---
title: handlers
---

# `marvin.handlers`

## Submodules
- [`handlers`](marvin-handlers-handlers)
- [`print_handler`](marvin-handlers-print_handler)
- [`queue_handler`](marvin-handlers-queue_handler)

---

**Parent Module:** [`marvin`](marvin)
